@@ -1,4 +1,4 @@
-from datetime import datetime
+from datetime import datetime, timedelta
 from typing import Union, Tuple
 
 import pandas as pd
@@ -19,3 +19,18 @@ def is_timezone_aware(tst: pd.Timestamp):
 
 def min_timestamp():
     return pd.Timestamp.min.tz_localize('UTC')
+
+
+def make_timeindex(from_tst: pd.Timestamp, nr_of_timesteps: int, only_weekdays=False, include_start_date=False):
+    tst = from_tst
+    forecast_tst = []
+
+    while len(forecast_tst) < nr_of_timesteps:
+        tst += timedelta(days=1)
+
+        if only_weekdays and tst.isoweekday() > 5:
+            continue
+
+        forecast_tst.append(tst)
+
+    return ([from_tst] if include_start_date else []) + forecast_tst
